==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_fa.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=fa
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'alerte_confirmer_suppression_signatures' => 'شما داريد تمام امضاهاي اين طومار را حذف مي‌كنيد. مطمئن هستيد كه مي‌خواهيد ادامه دهيد؟',
	'aucune_signature' => 'هيچ امضا',

	// B
	'bouton_checkbox_envoi_message' => 'امكان ارسال يك پيام',
	'bouton_checkbox_indiquer_site' => 'معرفي الزامي يك وب سايت',
	'bouton_checkbox_signature_unique_email' => 'فقط يك امضا براي نشاني ايميل ',
	'bouton_checkbox_signature_unique_site' => 'فقط يك امضا براي يك وب سايت',

	// F
	'filtre' => 'فيتلر:',
	'form_pet_adresse_site' => 'نشاني يوآر.ال سايت شما',
	'form_pet_aucune_signature' => '...هيچ امضائى با اين كد مطابقت نمي‌كند  ',
	'form_pet_confirmation' => ':خواهشمند است امضاء تان را تأئيد كنيد',
	'form_pet_deja_signe' => '.شما قبلأ اين متن را امضاء كرده ايد',
	'form_pet_envoi_mail_confirmation' => 'يك نامه الكترونيكي تأئيد به @email@ برايتان فرستاده شده. شما براي تأييد امضاي خود بايد به نشاني وب ذكر شده در آن نامه مراجعه نمائيد.',
	'form_pet_mail_confirmation' => 'سلام,
 
 شما تقاضاى امضاء يك درخواست راكرده ايد    @titre@.

: شما اطلاعات زير را بما داده ايد:
    
@nom_email@:نام @nom_site@-@url_site@سايت :
مهم  
 براى تأئيد امضاء تان، كافيست كه به آدرس زير متصل شويد ( در غير اين صورت درخواستتان رد 
خواهد شد
    @url@

از شركتتان متشكريم
 ',
	'form_pet_message_commentaire' => 'يك نظر؟',
	'form_pet_nom_site2' => 'نام وب سايت شما      ',
	'form_pet_probleme_liens' => 'خواهشمند است پیامتان را با حذف پیوند هایپرتکت دریافت کنید.',
	'form_pet_probleme_technique' => 'نقص فنى، امضاء ها موقتأ لغو شدند',
	'form_pet_signature_validee' => 'امضاء تان تأئيد شد. متشكريم !',
	'form_pet_site_deja_enregistre' => 'اين سايت قبلأ ثبت شده',
	'form_pet_url_invalide' => 'كه مشخص كرده ايد معتبر نميباشد URL ',
	'form_pet_votre_email' => 'آدرس ايميل تان',
	'form_pet_votre_nom' => 'نام شما',
	'form_pet_votre_site' => 'اگر داراى سايتى هستيد، ميتوانيد آنرا در زير ذكر كنيد',

	// I
	'icone_relancer_signataire' => 'بازنشر امضا كننده',
	'icone_relancer_signataires' => 'بازنشر امضاءكنندگان',
	'icone_suivi_petitions' => 'پيگيري/اداره طومارها',
	'icone_supprimer_signature' => 'حذف اين امضا',
	'icone_supprimer_signatures' => 'حذف امضاها',
	'icone_valider_signature' => 'تأييد اين امضا',
	'icone_valider_signatures' => 'تأييد امضاها',
	'info_adresse_email' => ': آدرس ايميل',
	'info_fonctionnement_petition' => 'عملكرد طومار:',
	'info_signature_supprimee' => 'امضا حذف شده',
	'info_signature_supprimee_erreur' => 'خطا: این کد حذف با هیچ امضائی منطبق نيست',
	'info_site_web' => ':تارنمای سايت ',
	'info_texte_message' => 'متن پيام شما',

	// L
	'lien_reponse_article' => 'پاسخ به مقاله',

	// N
	'nombre_signatures' => 'امضا@nb@',

	// S
	'sans_nom' => 'بدون امضا',
	'signatures_article' => 'امضاهاي مقاله:',
	'signatures_aucune' => 'هيچ',
	'signatures_meme_auteur' => 'امضاهاي همان نويسنده',
	'signatures_meme_site' => 'امضاها با همان سايت',
	'signatures_poubelle' => 'حذفي‌ها',
	'signatures_prop' => 'در انتظار',
	'signatures_publie' => 'تأييد شده‌ها',
	'signatures_recherche_label' => 'جستجوي امضاها:',
	'signatures_toutes' => 'همه',
	'statut_poubelle' => 'به سبدباطله',
	'statut_prop' => 'در انتظار تأييد',
	'statut_publie' => 'تأييد شده',

	// T
	'texte_descriptif_petition' => 'توصيف طومار',
	'titre_page_controle_petition' => 'پيگيري طومارها',
	'titre_petition' => 'طومار',
	'titre_petitions' => 'طومارها (درخواست‌ها)',
	'titre_selection_action' => 'گزينش',
	'titre_signatures_attente' => 'امضاهاي در انتظار تأييد',
	'titre_signatures_publie' => 'امضاهاي تأييد شده',
	'titre_suivi_petition' => 'پيگيري درخواست‌ها (طومارها)',
	'tout_voir' => 'ديدن تمام امضاها',

	// U
	'une_signature' => '1 امضا',

	// V
	'voir_signatures_objet' => 'ديدن امضاها'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_fa.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=fa
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'alerte_confirmer_suppression_signatures' => 'شما داريد تمام امضاهاي اين طومار را حذف مي‌كنيد. مطمئن هستيد كه مي‌خواهيد ادامه دهيد؟',
	'aucune_signature' => 'هيچ امضا',

	// B
	'bouton_checkbox_envoi_message' => 'امكان ارسال يك پيام',
	'bouton_checkbox_indiquer_site' => 'معرفي الزامي يك وب سايت',
	'bouton_checkbox_signature_unique_email' => 'فقط يك امضا براي نشاني ايميل ',
	'bouton_checkbox_signature_unique_site' => 'فقط يك امضا براي يك وب سايت',
	'bouton_radio_activer_petition' => 'درخواست را فعال كنيد',
	'bouton_radio_pas_petition' => 'بدون درخواست',
	'bouton_radio_petition_activee' => 'درخواست، فعال شده',
	'bouton_radio_supprimer_petition' => 'حذف درخواست',

	// F
	'filtre' => 'فيتلر:',
	'form_pet_adresse_site' => 'نشاني يوآر.ال سايت شما',
	'form_pet_aucune_signature' => '...هيچ امضائى با اين كد مطابقت نمي‌كند  ',
	'form_pet_confirmation' => ':خواهشمند است امضاء تان را تأئيد كنيد',
	'form_pet_deja_signe' => '.شما قبلأ اين متن را امضاء كرده ايد',
	'form_pet_envoi_mail_confirmation' => 'يك نامه الكترونيكي تأئيد به @email@ برايتان فرستاده شده. شما براي تأييد امضاي خود بايد به نشاني وب ذكر شده در آن نامه مراجعه نمائيد.',
	'form_pet_mail_confirmation' => 'سلام,
 
 شما تقاضاى امضاء يك درخواست راكرده ايد    @titre@.

: شما اطلاعات زير را بما داده ايد:
    
@nom_email@:نام @nom_site@-@url_site@سايت :
مهم  
 براى تأئيد امضاء تان، كافيست كه به آدرس زير متصل شويد ( در غير اين صورت درخواستتان رد 
خواهد شد
    @url@

از شركتتان متشكريم
 ',
	'form_pet_message_commentaire' => 'يك نظر؟',
	'form_pet_nom_site2' => 'نام وب سايت شما      ',
	'form_pet_probleme_liens' => 'خواهشمند است پیامتان را با حذف پیوند هایپرتکت دریافت کنید.',
	'form_pet_probleme_technique' => 'نقص فنى، امضاء ها موقتأ لغو شدند',
	'form_pet_signature_validee' => 'امضاء تان تأئيد شد. متشكريم !',
	'form_pet_site_deja_enregistre' => 'اين سايت قبلأ ثبت شده',
	'form_pet_url_invalide' => 'كه مشخص كرده ايد معتبر نميباشد URL ',
	'form_pet_votre_email' => 'آدرس ايميل تان',
	'form_pet_votre_nom' => 'نام شما',
	'form_pet_votre_site' => 'اگر داراى سايتى هستيد، ميتوانيد آنرا در زير ذكر كنيد',

	// I
	'icone_relancer_signataire' => 'بازنشر امضا كننده',
	'icone_relancer_signataires' => 'بازنشر امضاءكنندگان',
	'icone_suivi_petitions' => 'پيگيري/اداره طومارها',
	'icone_supprimer_signature' => 'حذف اين امضا',
	'icone_supprimer_signatures' => 'حذف امضاها',
	'icone_valider_signature' => 'تأييد اين امضا',
	'icone_valider_signatures' => 'تأييد امضاها',
	'info_adresse_email' => ': آدرس ايميل',
	'info_fonctionnement_petition' => 'عملكرد طومار:',
	'info_signature_supprimee' => 'امضا حذف شده',
	'info_signature_supprimee_erreur' => 'خطا: این کد حذف با هیچ امضائی منطبق نيست',
	'info_site_web' => ':تارنمای سايت ',
	'info_texte_message' => 'متن پيام شما',

	// L
	'lien_reponse_article' => 'پاسخ به مقاله',

	// N
	'nombre_signatures' => 'امضا@nb@',

	// S
	'sans_nom' => 'بدون امضا',
	'signatures_article' => 'امضاهاي مقاله:',
	'signatures_aucune' => 'هيچ',
	'signatures_meme_auteur' => 'امضاهاي همان نويسنده',
	'signatures_meme_site' => 'امضاها با همان سايت',
	'signatures_poubelle' => 'حذفي‌ها',
	'signatures_prop' => 'در انتظار',
	'signatures_publie' => 'تأييد شده‌ها',
	'signatures_recherche_label' => 'جستجوي امضاها:',
	'signatures_toutes' => 'همه',
	'statut_poubelle' => 'به سبدباطله',
	'statut_prop' => 'در انتظار تأييد',
	'statut_publie' => 'تأييد شده',

	// T
	'texte_descriptif_petition' => 'توصيف طومار',
	'titre_page_controle_petition' => 'پيگيري طومارها',
	'titre_petition' => 'طومار',
	'titre_petitions' => 'طومارها (درخواست‌ها)',
	'titre_selection_action' => 'گزينش',
	'titre_signatures_attente' => 'امضاهاي در انتظار تأييد',
	'titre_signatures_publie' => 'امضاهاي تأييد شده',
	'titre_suivi_petition' => 'پيگيري درخواست‌ها (طومارها)',
	'tout_voir' => 'ديدن تمام امضاها',

	// U
	'une_signature' => '1 امضا',

	// V
	'voir_signatures_objet' => 'ديدن امضاها'
);

?>
